lilypondfiletools
=================

.. automodule:: abjad.tools.lilypondfiletools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock
      ~abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.BookBlock.BookBlock
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock
      ~abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken
      ~abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock
      ~abjad.tools.lilypondfiletools.LilyPondDimension.LilyPondDimension
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile
      ~abjad.tools.lilypondfiletools.LilyPondLanguageToken.LilyPondLanguageToken
      ~abjad.tools.lilypondfiletools.LilyPondVersionToken.LilyPondVersionToken
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.make_basic_lilypond_file.make_basic_lilypond_file
      ~abjad.tools.lilypondfiletools.make_floating_time_signature_lilypond_file.make_floating_time_signature_lilypond_file
      ~abjad.tools.lilypondfiletools.make_time_signature_context_block.make_time_signature_context_block
